Package: makecdfenv
Version: 1.88.0
Date: 2006-03-06
Title: CDF Environment Maker
Author: Rafael A. Irizarry <rafa@jhu.edu>, Laurent Gautier
        <laurent@cbs.dtu.dk>, Wolfgang Huber
        <w.huber@dkfz-heidelberg.de>, Ben Bolstad <bmb@bmbolstad.com>
Maintainer: James W. MacDonald <jmacdon@u.washington.edu>
Depends: R (>= 2.6.0), affyio
Imports: Biobase, affy, methods, stats, utils
Description: This package has two functions. One reads a Affymetrix
        chip description file (CDF) and creates a hash table
        environment containing the location/probe set membership
        mapping. The other creates a package that automatically loads
        that environment.
License: GPL (>= 2)
LazyLoad: yes
biocViews: OneChannel, DataImport, Preprocessing
Config/pak/sysreqs: zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:30:06 UTC
RemoteUrl: https://github.com/bioc/makecdfenv
RemoteRef: RELEASE_3_23
RemoteSha: 1ae1a3cf4b27c9035ae57f9d435c1692e6415836
NeedsCompilation: yes
Packaged: 2026-04-29 23:10:39 UTC; root
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 23:14:48 UTC; unix
