Package: makecdfenv
Version: 1.88.0
Date: 2006-03-06
Title: CDF Environment Maker
Author: Rafael A. Irizarry <rafa@jhu.edu>, Laurent Gautier
        <laurent@cbs.dtu.dk>, Wolfgang Huber
        <w.huber@dkfz-heidelberg.de>, Ben Bolstad
        <bmb@bmbolstad.com>
Maintainer: James W. MacDonald <jmacdon@u.washington.edu>
Depends: R (>= 2.6.0), affyio
Imports: Biobase, affy, methods, stats, utils
Description: This package has two functions. One reads a Affymetrix
        chip description file (CDF) and creates a hash table
        environment containing the location/probe set membership
        mapping. The other creates a package that automatically loads
        that environment.
License: GPL (>= 2)
LazyLoad: yes
biocViews: OneChannel, DataImport, Preprocessing
git_url: https://git.bioconductor.org/packages/makecdfenv
git_branch: RELEASE_3_23
git_last_commit: 1ae1a3c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 22:59:37 UTC; biocbuild
