Package: @PKGNAME@
Title: @PKGNAME@
Version: @VERSION@
Created: @TODAY@
Author: @AUTHOR@
Description: A package containing an environment representing the @CDFFILENAME@ file.
Maintainer: @MAINTAINER@
License: LGPL
biocViews: AnnotationData, AffymetrixChip, cdf, @PKGROOT@, @SPECIES@
Depends: utils
Imports: AnnotationDbi
